DataTypeMap

Struct DataTypeMap 

pub struct DataTypeMap {
    pub arrow_type: PyDataType,
    pub python_type: PythonType,
    pub sql_type: SqlType,
}
These bindings are tying together several disparate systems. You have SQL types for the SQL strings and RDBMS systems itself. Rust types for the DataFusion code Arrow types which represents the underlying arrow format Python types which represent the type in Python It is important to keep all of those types in a single and manageable location. Therefore this structure exists to map those types and provide a simple place for developers to map types from one system to another.

Fields

arrow_type: PyDataTypepython_type: PythonTypesql_type: SqlType

Implementations

Source

impl DataTypeMap

pub fn map_from_arrow_type(arrow_type: &DataType) -> Result<DataTypeMap, PyErr>

pub fn map_from_scalar_value( scalar_val: &ScalarValue, ) -> Result<DataTypeMap, PyErr>

Generate the DataTypeMap from a ScalarValue instance

pub fn map_from_scalar_to_arrow( scalar_val: &ScalarValue, ) -> Result<DataType, PyErr>

Maps a ScalarValue to an Arrow DataType

Source

impl DataTypeMap

pub fn py_new( arrow_type: PyDataType, python_type: PythonType, sql_type: SqlType, ) -> Self

pub fn py_map_from_parquet_type_str( parquet_str_type: String, ) -> PyResult<DataTypeMap>

When using pyarrow.parquet.read_metadata().schema.column(x).physical_type you are presented with a String type for schema rather than an object type. Here we make a best effort to convert that to a physical type.

pub fn py_map_from_arrow_type(arrow_type: &PyDataType) -> PyResult<DataTypeMap>

pub fn py_map_from_arrow_type_str( arrow_type_str: String, ) -> PyResult<DataTypeMap>

pub fn py_map_from_sql_type(sql_type: &SqlType) -> PyResult<DataTypeMap>

pub fn friendly_arrow_type_name(&self) -> PyResult<&str>

Unfortunately PyO3 does not allow for us to expose the DataType as an enum since we cannot directly annotate the Enum instance of dependency code. Therefore, here we provide an enum to mimic it.