pub struct PyScalarValue(pub ScalarValue);Expand description
A ScalarValue wrapped in a Python object. This struct allows for conversion
from a variety of Python objects into a ScalarValue. See
FromPyArrow::from_pyarrow_bound conversion details.
Tuple Fields
0: ScalarValueTrait Implementations
Sourceimpl Clone for PyScalarValue
impl Clone for PyScalarValue
Sourcefn clone(&self) -> PyScalarValue
fn clone(&self) -> PyScalarValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PyScalarValue
impl Debug for PyScalarValue
impl Eq for PyScalarValue
Sourceimpl From<PyScalarValue> for ScalarValue
impl From<PyScalarValue> for ScalarValue
Sourcefn from(value: PyScalarValue) -> Self
fn from(value: PyScalarValue) -> Self
Converts to this type from the input type.
Sourceimpl From<ScalarValue> for PyScalarValue
impl From<ScalarValue> for PyScalarValue
Sourcefn from(value: ScalarValue) -> Self
fn from(value: ScalarValue) -> Self
Converts to this type from the input type.
Sourceimpl FromPyArrow for PyScalarValue
impl FromPyArrow for PyScalarValue
Sourceimpl<'source> FromPyObject<'_, 'source> for PyScalarValue
impl<'source> FromPyObject<'_, 'source> for PyScalarValue
Sourceimpl Hash for PyScalarValue
impl Hash for PyScalarValue
Sourceimpl PartialEq for PyScalarValue
impl PartialEq for PyScalarValue
Sourcefn eq(&self, other: &PyScalarValue) -> bool
fn eq(&self, other: &PyScalarValue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PyScalarValue
impl PartialOrd for PyScalarValue
impl StructuralPartialEq for PyScalarValue