pub struct PyRuntimeEnvBuilder {
pub builder: RuntimeEnvBuilder,
}Expand description
Runtime options for a SessionContext
Fields
builder: RuntimeEnvBuilderTrait Implementations
Sourceimpl Clone for PyRuntimeEnvBuilder
impl Clone for PyRuntimeEnvBuilder
Sourcefn clone(&self) -> PyRuntimeEnvBuilder
fn clone(&self) -> PyRuntimeEnvBuilder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl DerefToPyAny for PyRuntimeEnvBuilder
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for PyRuntimeEnvBuilderwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for PyRuntimeEnvBuilderwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for PyRuntimeEnvBuilder
impl<'py> IntoPyObject<'py> for PyRuntimeEnvBuilder
Sourcetype Target = PyRuntimeEnvBuilder
type Target = PyRuntimeEnvBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyRuntimeEnvBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyRuntimeEnvBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyRuntimeEnvBuilder
impl PyClass for PyRuntimeEnvBuilder
Sourceimpl PyClassBaseType for PyRuntimeEnvBuilder
impl PyClassBaseType for PyRuntimeEnvBuilder
type LayoutAsBase = <PyRuntimeEnvBuilder as PyClassImpl>::Layout
type BaseNativeType = <PyRuntimeEnvBuilder as PyClassImpl>::BaseNativeType
type Initializer = PyClassInitializer<PyRuntimeEnvBuilder>
type PyClassMutability = <PyRuntimeEnvBuilder as PyClassImpl>::PyClassMutability
Sourcetype Layout<T: PyClassImpl> = <<PyRuntimeEnvBuilder as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
type Layout<T: PyClassImpl> = <<PyRuntimeEnvBuilder as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
The type of object layout to use for ancestors or descendants of this type.
Sourceimpl PyClassImpl for PyRuntimeEnvBuilder
impl PyClassImpl for PyRuntimeEnvBuilder
Sourceconst IS_BASETYPE: bool = true
const IS_BASETYPE: bool = true
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Runtime options for a SessionContext
const RAW_DOC: &'static CStr = /// Runtime options for a SessionContext
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyRuntimeEnvBuilder as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyRuntimeEnvBuilder>
type Layout = <<PyRuntimeEnvBuilder as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyRuntimeEnvBuilder>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for PyRuntimeEnvBuilder
impl PyClassNewTextSignature for PyRuntimeEnvBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyRuntimeEnvBuilder> for PyClassImplCollector<PyRuntimeEnvBuilder>
impl PyMethods<PyRuntimeEnvBuilder> for PyClassImplCollector<PyRuntimeEnvBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyRuntimeEnvBuilder
impl PyTypeInfo for PyRuntimeEnvBuilder
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.