pub struct PySessionContext {
pub ctx: Arc<SessionContext>,
/* private fields */
}Expand description
PySessionContext is able to plan and execute DataFusion plans.
It has a powerful optimizer, a physical planner for local execution, and a
multi-threaded execution engine to perform the execution.
Fields
ctx: Arc<SessionContext>Implementations
Sourceimpl PySessionContext
impl PySessionContext
pub fn new( config: Option<PySessionConfig>, runtime: Option<PyRuntimeEnvBuilder>, ) -> PyDataFusionResult<Self>
pub fn enable_url_table(&self) -> PyResult<Self>
pub fn global_ctx() -> PyResult<Self>
Sourcepub fn register_object_store(
&self,
scheme: &str,
store: StorageContexts,
host: Option<&str>,
) -> PyResult<()>
pub fn register_object_store( &self, scheme: &str, store: StorageContexts, host: Option<&str>, ) -> PyResult<()>
Register an object store with the given name
Sourcepub fn deregister_object_store(
&self,
scheme: &str,
host: Option<&str>,
) -> PyDataFusionResult<()>
pub fn deregister_object_store( &self, scheme: &str, host: Option<&str>, ) -> PyDataFusionResult<()>
Deregister an object store with the given url
pub fn register_listing_table( &self, name: &str, path: &str, table_partition_cols: Vec<(String, PyArrowType<DataType>)>, file_extension: &str, schema: Option<PyArrowType<Schema>>, file_sort_order: Option<Vec<Vec<PySortExpr>>>, py: Python<'_>, ) -> PyDataFusionResult<()>
pub fn register_udtf(&self, func: PyTableFunction)
pub fn deregister_udtf(&self, name: &str)
pub fn sql_with_options( &self, py: Python<'_>, query: String, options: Option<PySQLOptions>, param_values: HashMap<String, PyScalarValue>, param_strings: HashMap<String, String>, ) -> PyDataFusionResult<PyDataFrame>
pub fn create_dataframe( &self, partitions: PyArrowType<Vec<Vec<RecordBatch>>>, name: Option<&str>, schema: Option<PyArrowType<Schema>>, py: Python<'_>, ) -> PyDataFusionResult<PyDataFrame>
Sourcepub fn create_dataframe_from_logical_plan(
&self,
plan: PyLogicalPlan,
) -> PyDataFrame
pub fn create_dataframe_from_logical_plan( &self, plan: PyLogicalPlan, ) -> PyDataFrame
Create a DataFrame from an existing logical plan
Sourcepub fn from_pylist(
&self,
data: Bound<'_, PyList>,
name: Option<&str>,
) -> PyResult<PyDataFrame>
pub fn from_pylist( &self, data: Bound<'_, PyList>, name: Option<&str>, ) -> PyResult<PyDataFrame>
Construct datafusion dataframe from Python list
Sourcepub fn from_pydict(
&self,
data: Bound<'_, PyDict>,
name: Option<&str>,
) -> PyResult<PyDataFrame>
pub fn from_pydict( &self, data: Bound<'_, PyDict>, name: Option<&str>, ) -> PyResult<PyDataFrame>
Construct datafusion dataframe from Python dictionary
Sourcepub fn from_arrow(
&self,
data: Bound<'_, PyAny>,
name: Option<&str>,
py: Python<'_>,
) -> PyDataFusionResult<PyDataFrame>
pub fn from_arrow( &self, data: Bound<'_, PyAny>, name: Option<&str>, py: Python<'_>, ) -> PyDataFusionResult<PyDataFrame>
Construct datafusion dataframe from Arrow Table
Sourcepub fn from_pandas(
&self,
data: Bound<'_, PyAny>,
name: Option<&str>,
) -> PyResult<PyDataFrame>
pub fn from_pandas( &self, data: Bound<'_, PyAny>, name: Option<&str>, ) -> PyResult<PyDataFrame>
Construct datafusion dataframe from pandas
Sourcepub fn from_polars(
&self,
data: Bound<'_, PyAny>,
name: Option<&str>,
) -> PyResult<PyDataFrame>
pub fn from_polars( &self, data: Bound<'_, PyAny>, name: Option<&str>, ) -> PyResult<PyDataFrame>
Construct datafusion dataframe from polars
pub fn register_table( &self, name: &str, table: Bound<'_, PyAny>, ) -> PyDataFusionResult<()>
pub fn deregister_table(&self, name: &str) -> PyDataFusionResult<()>
pub fn register_table_factory( &self, format: &str, factory: Bound<'_, PyAny>, ) -> PyDataFusionResult<()>
pub fn register_catalog_provider_list( &self, provider: Bound<'_, PyAny>, ) -> PyDataFusionResult<()>
pub fn register_catalog_provider( &self, name: &str, provider: Bound<'_, PyAny>, ) -> PyDataFusionResult<()>
Sourcepub fn register_table_provider(
&self,
name: &str,
provider: Bound<'_, PyAny>,
) -> PyDataFusionResult<()>
pub fn register_table_provider( &self, name: &str, provider: Bound<'_, PyAny>, ) -> PyDataFusionResult<()>
Construct datafusion dataframe from Arrow Table
pub fn register_record_batches( &self, name: &str, partitions: PyArrowType<Vec<Vec<RecordBatch>>>, ) -> PyDataFusionResult<()>
pub fn register_parquet( &self, name: &str, path: &str, table_partition_cols: Vec<(String, PyArrowType<DataType>)>, parquet_pruning: bool, file_extension: &str, skip_metadata: bool, schema: Option<PyArrowType<Schema>>, file_sort_order: Option<Vec<Vec<PySortExpr>>>, py: Python<'_>, ) -> PyDataFusionResult<()>
pub fn register_csv( &self, name: &str, path: &Bound<'_, PyAny>, options: Option<&PyCsvReadOptions>, py: Python<'_>, ) -> PyDataFusionResult<()>
pub fn register_json( &self, name: &str, path: PathBuf, schema: Option<PyArrowType<Schema>>, schema_infer_max_records: usize, file_extension: &str, table_partition_cols: Vec<(String, PyArrowType<DataType>)>, file_compression_type: Option<String>, py: Python<'_>, ) -> PyDataFusionResult<()>
pub fn register_avro( &self, name: &str, path: PathBuf, schema: Option<PyArrowType<Schema>>, file_extension: &str, table_partition_cols: Vec<(String, PyArrowType<DataType>)>, py: Python<'_>, ) -> PyDataFusionResult<()>
pub fn register_arrow( &self, name: &str, path: &str, schema: Option<PyArrowType<Schema>>, file_extension: &str, table_partition_cols: Vec<(String, PyArrowType<DataType>)>, py: Python<'_>, ) -> PyDataFusionResult<()>
pub fn register_batch( &self, name: &str, batch: PyArrowType<RecordBatch>, ) -> PyDataFusionResult<()>
pub fn register_dataset( &self, name: &str, dataset: &Bound<'_, PyAny>, py: Python<'_>, ) -> PyDataFusionResult<()>
pub fn register_udf(&self, udf: PyScalarUDF) -> PyResult<()>
pub fn deregister_udf(&self, name: &str)
pub fn register_udaf(&self, udaf: PyAggregateUDF) -> PyResult<()>
pub fn deregister_udaf(&self, name: &str)
pub fn register_udwf(&self, udwf: PyWindowUDF) -> PyResult<()>
pub fn deregister_udwf(&self, name: &str)
pub fn catalog(&self, py: Python<'_>, name: &str) -> PyResult<Py<PyAny>>
pub fn catalog_names(&self) -> HashSet<String>
pub fn table(&self, name: &str, py: Python<'_>) -> PyResult<PyDataFrame>
pub fn table_exist(&self, name: &str) -> PyDataFusionResult<bool>
pub fn empty_table(&self) -> PyDataFusionResult<PyDataFrame>
pub fn session_id(&self) -> String
pub fn session_start_time(&self) -> String
pub fn enable_ident_normalization(&self) -> bool
pub fn parse_sql_expr( &self, sql: &str, schema: PyDFSchema, ) -> PyDataFusionResult<PyExpr>
pub fn execute_logical_plan( &self, plan: PyLogicalPlan, py: Python<'_>, ) -> PyDataFusionResult<PyDataFrame>
pub fn refresh_catalogs(&self, py: Python<'_>) -> PyDataFusionResult<()>
pub fn remove_optimizer_rule(&self, name: &str) -> bool
pub fn table_provider(&self, name: &str, py: Python<'_>) -> PyResult<PyTable>
pub fn read_json( &self, path: PathBuf, schema: Option<PyArrowType<Schema>>, schema_infer_max_records: usize, file_extension: &str, table_partition_cols: Vec<(String, PyArrowType<DataType>)>, file_compression_type: Option<String>, py: Python<'_>, ) -> PyDataFusionResult<PyDataFrame>
pub fn read_csv( &self, path: &Bound<'_, PyAny>, options: Option<&PyCsvReadOptions>, py: Python<'_>, ) -> PyDataFusionResult<PyDataFrame>
pub fn read_parquet( &self, path: &str, table_partition_cols: Vec<(String, PyArrowType<DataType>)>, parquet_pruning: bool, file_extension: &str, skip_metadata: bool, schema: Option<PyArrowType<Schema>>, file_sort_order: Option<Vec<Vec<PySortExpr>>>, py: Python<'_>, ) -> PyDataFusionResult<PyDataFrame>
pub fn read_avro( &self, path: &str, schema: Option<PyArrowType<Schema>>, table_partition_cols: Vec<(String, PyArrowType<DataType>)>, file_extension: &str, py: Python<'_>, ) -> PyDataFusionResult<PyDataFrame>
pub fn read_arrow( &self, path: &str, schema: Option<PyArrowType<Schema>>, file_extension: &str, table_partition_cols: Vec<(String, PyArrowType<DataType>)>, py: Python<'_>, ) -> PyDataFusionResult<PyDataFrame>
pub fn read_table( &self, table: Bound<'_, PyAny>, ) -> PyDataFusionResult<PyDataFrame>
Sourcepub fn execute(
&self,
plan: PyExecutionPlan,
part: usize,
py: Python<'_>,
) -> PyDataFusionResult<PyRecordBatchStream>
pub fn execute( &self, plan: PyExecutionPlan, part: usize, py: Python<'_>, ) -> PyDataFusionResult<PyRecordBatchStream>
Execute a partition of an execution plan and return a stream of record batches
pub fn __datafusion_task_context_provider__<'py>( &self, py: Python<'py>, ) -> PyResult<Bound<'py, PyCapsule>>
pub fn __datafusion_logical_extension_codec__<'py>( &self, py: Python<'py>, ) -> PyResult<Bound<'py, PyCapsule>>
pub fn with_logical_extension_codec<'py>( &self, codec: Bound<'py, PyAny>, ) -> PyDataFusionResult<Self>