pub struct FormatterConfig {
pub max_bytes: usize,
pub min_rows: usize,
pub max_rows: usize,
}Expand description
Configuration for DataFrame display formatting
Fields
max_bytes: usizeMaximum memory in bytes to use for display (default: 2MB)
min_rows: usizeMinimum number of rows to display (default: 10)
max_rows: usizeMaximum number of rows to include in repr output (default: 10)
Implementations