pub struct PyDataFrame { /* private fields */ }Expand description
A PyDataFrame is a representation of a logical plan and an API to compose statements.
Use it to build a plan and .collect() to execute the plan and collect the result.
The actual execution of a plan runs natively on Rust and Arrow on a multi-threaded environment.
Implementations
Sourceimpl PyDataFrame
impl PyDataFrame
Sourcepub fn into_view(&self, temporary: bool) -> PyDataFusionResult<PyTable>
pub fn into_view(&self, temporary: bool) -> PyDataFusionResult<PyTable>
Convert this DataFrame into a Table Provider that can be used in register_table By convention, into_… methods consume self and return the new object. Disabling the clippy lint, so we can use &self because we’re working with Python bindings where objects are shared