Crate csv

Crate csv 

Transfer data between the Apache Arrow memory format and CSV (comma-separated values).

Modules

reader
CSV Reading: Reader and ReaderBuilder
writer
CSV Writing: Writer and WriterBuilder

Structs

ReaderBuilder
Builder for CSV Readers
Writer
A CSV writer
WriterBuilder
A CSV writer builder

Enums

QuoteStyle
The quoting style to use when writing CSV data.

Functions

infer_schema_from_files
Infer schema from a list of CSV files by reading through first n records with max_read_records controlling the maximum number of records to read.

Type Aliases

Reader
CSV file reader using std::io::BufReader