Union

Struct Union 

pub struct Union<'a> {
    pub _tab: Table<'a>,
}
A union is a complex type with children in Field By default ids in the type vector refer to the offsets in the children optionally typeIds provides an indirection between the child offset and the type id for each child typeIds[offset] is the id used in the type vector

Fields

_tab: Table<'a>

Implementations

Source

impl<'a> Union<'a>

pub const VT_MODE: u16 = 4

pub const VT_TYPEIDS: u16 = 6

pub unsafe fn init_from_table(table: Table<'a>) -> Union<'a>

pub fn create<'bldr, 'args, 'mut_bldr, A>( _fbb: &'mut_bldr mut FlatBufferBuilder<'bldr, A>, args: &'args UnionArgs<'args>, ) -> WIPOffset<Union<'bldr>>
where 'bldr: 'args, 'args: 'mut_bldr, A: Allocator + 'bldr,

pub fn mode(&self) -> UnionMode

pub fn typeIds(&self) -> Option<Vector<'a, i32>>