BinaryView

Struct BinaryView 

pub struct BinaryView<'a> {
    pub _tab: Table<'a>,
}
Logically the same as Binary, but the internal representation uses a view struct that contains the string length and either the string’s entire data inline (for small strings) or an inlined prefix, an index of another buffer, and an offset pointing to a slice in that buffer (for non-small strings).

Since it uses a variable number of data buffers, each Field with this type must have a corresponding entry in variadicBufferCounts.

Fields

_tab: Table<'a>

Implementations

Source

impl<'a> BinaryView<'a>

pub unsafe fn init_from_table(table: Table<'a>) -> BinaryView<'a>

pub fn create<'bldr, 'args, 'mut_bldr, A>( _fbb: &'mut_bldr mut FlatBufferBuilder<'bldr, A>, _args: &'args BinaryViewArgs, ) -> WIPOffset<BinaryView<'bldr>>
where 'bldr: 'args, 'args: 'mut_bldr, A: Allocator + 'bldr,