DecoderContext

Struct DecoderContext 

pub struct DecoderContext { /* private fields */ }
Context for decoder creation, containing configuration.

This context is passed through the decoder creation process and contains all the configuration needed to create decoders recursively.

Implementations

Source

impl DecoderContext

pub fn coerce_primitive(&self) -> bool

Returns whether to coerce primitive types (e.g., number to string)

pub fn strict_mode(&self) -> bool

Returns whether to validate struct fields strictly

pub fn struct_mode(&self) -> StructMode

Returns how to decode struct fields

pub fn ignore_type_conflicts(&self) -> bool

Returns whether to treat columns with incompatible types as missing (i.e. NULL)