pub struct EncoderOptions { /* private fields */ }Expand description
Configuration options for the JSON encoder.
Implementations
Sourceimpl EncoderOptions
impl EncoderOptions
Sourcepub fn with_explicit_nulls(self, explicit_nulls: bool) -> EncoderOptions
pub fn with_explicit_nulls(self, explicit_nulls: bool) -> EncoderOptions
Set whether to include nulls in the output or elide them.
Sourcepub fn with_struct_mode(self, struct_mode: StructMode) -> EncoderOptions
pub fn with_struct_mode(self, struct_mode: StructMode) -> EncoderOptions
Set whether to encode structs as JSON objects or JSON arrays of their values.
Sourcepub fn with_encoder_factory(
self,
encoder_factory: Arc<dyn EncoderFactory>,
) -> EncoderOptions
pub fn with_encoder_factory( self, encoder_factory: Arc<dyn EncoderFactory>, ) -> EncoderOptions
Set an optional hook for customizing encoding behavior.
Sourcepub fn explicit_nulls(&self) -> bool
pub fn explicit_nulls(&self) -> bool
Get whether to include nulls in the output or elide them.
Sourcepub fn struct_mode(&self) -> StructMode
pub fn struct_mode(&self) -> StructMode
Get whether to encode structs as JSON objects or JSON arrays of their values.
Sourcepub fn encoder_factory(&self) -> Option<&Arc<dyn EncoderFactory>>
pub fn encoder_factory(&self) -> Option<&Arc<dyn EncoderFactory>>
Get the optional hook for customizing encoding behavior.
Sourcepub fn with_date_format(self, format: String) -> EncoderOptions
pub fn with_date_format(self, format: String) -> EncoderOptions
Set the JSON file’s date format
Sourcepub fn date_format(&self) -> Option<&str>
pub fn date_format(&self) -> Option<&str>
Get the JSON file’s date format if set, defaults to RFC3339
Sourcepub fn with_datetime_format(self, format: String) -> EncoderOptions
pub fn with_datetime_format(self, format: String) -> EncoderOptions
Set the JSON file’s datetime format
Sourcepub fn datetime_format(&self) -> Option<&str>
pub fn datetime_format(&self) -> Option<&str>
Get the JSON file’s datetime format if set, defaults to RFC3339
Sourcepub fn with_time_format(self, format: String) -> EncoderOptions
pub fn with_time_format(self, format: String) -> EncoderOptions
Set the JSON file’s time format
Sourcepub fn time_format(&self) -> Option<&str>
pub fn time_format(&self) -> Option<&str>
Get the JSON file’s datetime time if set, defaults to RFC3339
Sourcepub fn with_timestamp_format(self, format: String) -> EncoderOptions
pub fn with_timestamp_format(self, format: String) -> EncoderOptions
Set the JSON file’s timestamp format
Sourcepub fn timestamp_format(&self) -> Option<&str>
pub fn timestamp_format(&self) -> Option<&str>
Get the JSON file’s timestamp format if set, defaults to RFC3339
Sourcepub fn with_timestamp_tz_format(self, tz_format: String) -> EncoderOptions
pub fn with_timestamp_tz_format(self, tz_format: String) -> EncoderOptions
Set the JSON file’s timestamp tz format
Sourcepub fn timestamp_tz_format(&self) -> Option<&str>
pub fn timestamp_tz_format(&self) -> Option<&str>
Get the JSON file’s timestamp tz format if set, defaults to RFC3339