Writer

Struct Writer 

pub struct Writer<W, F>
where W: Write, F: JsonFormat,
{ /* private fields */ }
A JSON writer which serializes RecordBatches to a stream of u8 encoded JSON objects.

See the module level documentation for detailed usage and examples. The specific format of the stream is controlled by the JsonFormat type parameter.

By default the writer will skip writing keys with null values for backward compatibility. See WriterBuilder on how to customize this behaviour when creating a new writer.

Implementations

Source

impl<W, F> Writer<W, F>
where W: Write, F: JsonFormat,

pub fn new(writer: W) -> Writer<W, F>

Construct a new writer

pub fn write(&mut self, batch: &RecordBatch) -> Result<(), ArrowError>

Serialize batch to JSON output

pub fn write_batches( &mut self, batches: &[&RecordBatch], ) -> Result<(), ArrowError>

Serialize batches to JSON output

pub fn finish(&mut self) -> Result<(), ArrowError>

Finishes the output stream. This function must be called after all record batches have been produced. (e.g. producing the final ']' if writing arrays.

pub fn get_ref(&self) -> &W

Gets a reference to the underlying writer.

pub fn get_mut(&mut self) -> &mut W

Gets a mutable reference to the underlying writer.

Writing to the underlying writer must be done with care to avoid corrupting the output JSON.

pub fn into_inner(self) -> W

Unwraps this Writer<W>, returning the underlying writer