pub trait JsonFormat: Debug + Default {
// Provided methods
fn start_stream<W>(&self, _writer: &mut W) -> Result<(), ArrowError>
where W: Write { ... }
fn start_row<W>(
&self,
_writer: &mut W,
_is_first_row: bool,
) -> Result<(), ArrowError>
where W: Write { ... }
fn end_row<W>(&self, _writer: &mut W) -> Result<(), ArrowError>
where W: Write { ... }
fn end_stream<W>(&self, _writer: &mut W) -> Result<(), ArrowError>
where W: Write { ... }
}Expand description
This trait defines how to format a sequence of JSON objects to a byte stream.
Provided Methods
Sourcefn start_stream<W>(&self, _writer: &mut W) -> Result<(), ArrowError>where
W: Write,
fn start_stream<W>(&self, _writer: &mut W) -> Result<(), ArrowError>where
W: Write,
write any bytes needed at the start of the file to the writer
Sourcefn start_row<W>(
&self,
_writer: &mut W,
_is_first_row: bool,
) -> Result<(), ArrowError>where
W: Write,
fn start_row<W>(
&self,
_writer: &mut W,
_is_first_row: bool,
) -> Result<(), ArrowError>where
W: Write,
write any bytes needed for the start of each row
Sourcefn end_row<W>(&self, _writer: &mut W) -> Result<(), ArrowError>where
W: Write,
fn end_row<W>(&self, _writer: &mut W) -> Result<(), ArrowError>where
W: Write,
write any bytes needed for the end of each row
Sourcefn end_stream<W>(&self, _writer: &mut W) -> Result<(), ArrowError>where
W: Write,
fn end_stream<W>(&self, _writer: &mut W) -> Result<(), ArrowError>where
W: Write,
write any bytes needed for the start of each row
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".