Table

Struct Table 

pub struct Table { /* private fields */ }
This is a convenience wrapper around Vec<RecordBatch> that tries to simplify conversion from and to pyarrow.Table.

This could be used in circumstances where you either want to consume a pyarrow.Table directly (although technically, since pyarrow.Table implements the ArrayStreamReader PyCapsule interface, one could also consume a PyArrowType<ArrowArrayStreamReader> instead) or, more importantly, where one wants to export a pyarrow.Table from a Vec<RecordBatch> from the Rust side.

#[pyfunction]
fn return_table(...) -> PyResult<PyArrowType<Table>> {
    let batches: Vec<RecordBatch>;
    let schema: SchemaRef;
    PyArrowType(Table::try_new(batches, schema).map_err(|err| err.into_py_err(py))?)
}

Implementations

Source

impl Table

pub fn try_new( record_batches: Vec<RecordBatch>, schema: Arc<Schema>, ) -> Result<Table, ArrowError>

pub fn record_batches(&self) -> &[RecordBatch]

pub fn schema(&self) -> Arc<Schema>

pub fn into_inner(self) -> (Vec<RecordBatch>, Arc<Schema>)