pub struct OwnedRow { /* private fields */ }Expand description
Owned version of a Row that can be moved/cloned freely.
This contains the data for the one specific row (not the entire buffer of all rows).
Implementations