BitChunks

pub struct BitChunks<'a> { /* private fields */ }
Iterates over an arbitrarily aligned byte buffer 64 bits at a time

Self::iter yields iterator of u64, and a remainder. The first byte in the buffer will be the least significant byte in output u64

Implementations

Source

impl<'a> BitChunks<'a>

pub fn new(buffer: &'a [u8], offset: usize, len: usize) -> BitChunks<'a>

Create a new BitChunks from a byte array, and an offset and length in bits

Source

impl<'a> BitChunks<'a>

pub const fn remainder_len(&self) -> usize

Returns the number of remaining bits, guaranteed to be between 0 and 63 (inclusive)

pub const fn chunk_len(&self) -> usize

Returns the number of u64 chunks

pub fn remainder_bits(&self) -> u64

Returns the bitmask of remaining bits

pub fn num_u64s(&self) -> usize

Return the number of u64 that are needed to represent all bits (including remainder).

This is equal to chunk_len + 1 if there is a remainder, otherwise it is equal to chunk_len.

pub fn num_bytes(&self) -> usize

Return the number of bytes that are needed to represent all bits (including remainder).

pub const fn iter(&self) -> BitChunkIterator<'a>

Returns an iterator over chunks of 64 bits represented as an u64

pub fn iter_padded(&self) -> impl Iterator<Item = u64> + 'a

Returns an iterator over chunks of 64 bits, with the remaining bits zero padded to 64-bits