pub struct JsonOptions {
pub compression: CompressionTypeVariant,
pub compression_level: Option<u32>,
pub schema_infer_max_rec: Option<usize>,
pub newline_delimited: bool,
}Expand description
Options controlling JSON format
Fields
compression: CompressionTypeVariantcompression_level: Option<u32>Compression level for the output file. The valid range depends on the compression algorithm:
- ZSTD: 1 to 22 (default: 3)
- GZIP: 0 to 9 (default: 6)
- BZIP2: 0 to 9 (default: 6)
- XZ: 0 to 9 (default: 6) If not specified, the default level for the compression algorithm is used.
schema_infer_max_rec: Option<usize>newline_delimited: boolThe JSON format to use when reading files.
When true (default), expects newline-delimited JSON (NDJSON):
{"key1": 1, "key2": "val"}
{"key1": 2, "key2": "vals"}When false, expects JSON array format:
[
{"key1": 1, "key2": "val"},
{"key1": 2, "key2": "vals"}
]Trait Implementations
Sourceimpl Clone for JsonOptions
impl Clone for JsonOptions
Sourcefn clone(&self) -> JsonOptions
fn clone(&self) -> JsonOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConfigField for JsonOptions
impl ConfigField for JsonOptions
Sourceimpl Debug for JsonOptions
impl Debug for JsonOptions
Sourceimpl Default for JsonOptions
impl Default for JsonOptions
Sourcefn default() -> JsonOptions
fn default() -> JsonOptions
Returns the “default value” for a type. Read more
Sourceimpl From<&JsonOptions> for JsonOptions
impl From<&JsonOptions> for JsonOptions
Sourcefn from(proto: &JsonOptions) -> JsonOptions
fn from(proto: &JsonOptions) -> JsonOptions
Converts to this type from the input type.
Sourceimpl PartialEq for JsonOptions
impl PartialEq for JsonOptions
Sourcefn eq(&self, other: &JsonOptions) -> bool
fn eq(&self, other: &JsonOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for JsonOptions
Sourceimpl TryFrom<&JsonOptions> for JsonWriterOptions
impl TryFrom<&JsonOptions> for JsonWriterOptions
Sourcetype Error = DataFusionError
type Error = DataFusionError
The type returned in the event of a conversion error.
Sourcefn try_from(value: &JsonOptions) -> Result<JsonWriterOptions, DataFusionError>
fn try_from(value: &JsonOptions) -> Result<JsonWriterOptions, DataFusionError>
Performs the conversion.
Sourceimpl TryFrom<&JsonOptions> for JsonOptions
impl TryFrom<&JsonOptions> for JsonOptions
Sourcetype Error = DataFusionError
type Error = DataFusionError
The type returned in the event of a conversion error.
Sourcefn try_from(
proto_opts: &JsonOptions,
) -> Result<JsonOptions, <JsonOptions as TryFrom<&JsonOptions>>::Error>
fn try_from( proto_opts: &JsonOptions, ) -> Result<JsonOptions, <JsonOptions as TryFrom<&JsonOptions>>::Error>
Performs the conversion.