pub struct SpawnedTask<R> { /* private fields */ }Expand description
Helper that provides a simple API to spawn a single task and join it.
Provides guarantees of aborting on Drop to keep it cancel-safe.
Note that if the task was spawned with spawn_blocking, it will only be
aborted if it hasn’t started yet.
Technically, it’s just a wrapper of a JoinHandle overriding drop.
Implementations
Sourceimpl<R> SpawnedTask<R>where
R: 'static,
impl<R> SpawnedTask<R>where
R: 'static,
pub fn spawn<T>(task: T) -> SpawnedTask<R> ⓘ
pub fn spawn_blocking<T>(task: T) -> SpawnedTask<R> ⓘ
Sourcepub async fn join(self) -> Result<R, JoinError>
pub async fn join(self) -> Result<R, JoinError>
Joins the task, returning the result of join (Result<R, JoinError>).
Same as awaiting the spawned task, but left for backwards compatibility.
Sourcepub async fn join_unwind(self) -> Result<R, JoinError>
pub async fn join_unwind(self) -> Result<R, JoinError>
Joins the task and unwinds the panic if it happens.
Sourcepub async fn join_unwind_mut(&mut self) -> Result<R, JoinError>
pub async fn join_unwind_mut(&mut self) -> Result<R, JoinError>
Joins the task using a mutable reference and unwinds the panic if it happens.
This method is similar to join_unwind, but takes a mutable
reference instead of consuming self. This allows the SpawnedTask to remain
usable after the call.
If called multiple times on the same task:
- If the task is still running, it will continue waiting for completion
- If the task has already completed successfully, subsequent calls will
continue to return the same
JoinErrorindicating the task is finished - If the task panicked, the first call will resume the panic, and the program will not reach subsequent calls