pub fn date_to_timestamp_multiplier(
source_type: &DataType,
target_type: &DataType,
) -> Option<i64>Expand description
Returns the multiplier that converts the input date representation into the
desired timestamp unit, if the conversion requires a multiplication that can
overflow an i64.