ensure_timestamp_in_bounds

Function ensure_timestamp_in_bounds 

pub fn ensure_timestamp_in_bounds(
    value: i64,
    multiplier: i64,
    source_type: &DataType,
    target_type: &DataType,
) -> Result<(), DataFusionError>
Ensures the provided value can be represented as a timestamp with the given multiplier. Returns an DataFusionError::Execution when the converted value would overflow the timestamp range.