pub struct DFTimestampWithOffset { /* private fields */ }Expand description
Defines the extension type logic for the canonical arrow.timestamp_with_offset extension type.
This extension type allows associating a different offset for each timestamp in a column.
See DFExtensionType for information on DataFusion’s extension type mechanism. See also
TimestampWithOffset for the implementation of arrow-rs, which this type uses internally.
https://arrow.apache.org/docs/format/CanonicalExtensions.html#timestamp-with-offset
Implementations
Sourceimpl DFTimestampWithOffset
impl DFTimestampWithOffset
Sourcepub fn try_new(
data_type: &DataType,
metadata: <TimestampWithOffset as ExtensionType>::Metadata,
) -> Result<DFTimestampWithOffset, DataFusionError>
pub fn try_new( data_type: &DataType, metadata: <TimestampWithOffset as ExtensionType>::Metadata, ) -> Result<DFTimestampWithOffset, DataFusionError>
Creates a new DFTimestampWithOffset, validating that the storage type is compatible with
the extension type.