pub fn adjust_offsets_for_slice<O>(
list: &GenericListArray<O>,
) -> OffsetBuffer<O>where
O: OffsetSizeTrait,Expand description
If list is sliced, returns an adjusted offset buffer so that
it points to the sliced portion of the list values, and not the whole list values