pub enum TypeSignatureClass {
Any,
Timestamp,
Time,
Interval,
Duration,
Native(Arc<dyn LogicalType>),
Integer,
Float,
Decimal,
Numeric,
Binary,
}Expand description
Represents the class of types that can be used in a function signature.
This is used to specify what types are valid for function arguments in a more flexible way than just listing specific DataTypes. For example, TypeSignatureClass::Timestamp matches any timestamp type regardless of timezone or precision.
Used primarily with TypeSignature::Coercible to define function signatures that can accept
arguments that can be coerced to a particular class of types.
Variants
Any
Allows an arbitrary type argument without coercing the argument.
Timestamp
Timestamps, allowing arbitrary (or no) timezones
Time
All time types
Interval
All interval types
Duration
All duration types
Native(Arc<dyn LogicalType>)
A specific native type
Integer
Signed and unsigned integers
Float
All float types
Decimal
All decimal types, allowing arbitrary precision & scale
Numeric
Integers, floats and decimals
Binary
Encompasses both the native Binary/LargeBinary types as well as arbitrarily sized FixedSizeBinary types
Implementations
Sourceimpl TypeSignatureClass
impl TypeSignatureClass
Sourcepub fn matches_native_type(&self, logical_type: &NativeType) -> bool
pub fn matches_native_type(&self, logical_type: &NativeType) -> bool
Does the specified NativeType match this type signature class?
Sourcepub fn default_casted_type(
&self,
native_type: &NativeType,
origin_type: &DataType,
) -> Result<DataType, DataFusionError>
pub fn default_casted_type( &self, native_type: &NativeType, origin_type: &DataType, ) -> Result<DataType, DataFusionError>
What type would origin_type be casted to when casting to the specified native type?