pub struct HigherOrderFunction {
pub func: Arc<HigherOrderUDF>,
pub args: Vec<Expr>,
}Expand description
Invoke a HigherOrderUDF with a set of arguments
Fields
func: Arc<HigherOrderUDF>The function
args: Vec<Expr>List of expressions to feed to the functions as arguments
Implementations
Sourceimpl HigherOrderFunction
impl HigherOrderFunction
Sourcepub fn new(func: Arc<HigherOrderUDF>, args: Vec<Expr>) -> HigherOrderFunction
pub fn new(func: Arc<HigherOrderUDF>, args: Vec<Expr>) -> HigherOrderFunction
Create a new HigherOrderFunction from a HigherOrderUDF
pub fn name(&self) -> &str
Sourcepub fn lambda_parameters(
&self,
schema: &dyn ExprSchema,
) -> Result<Vec<Vec<Arc<Field>>>, DataFusionError>
pub fn lambda_parameters( &self, schema: &dyn ExprSchema, ) -> Result<Vec<Vec<Arc<Field>>>, DataFusionError>
Invokes the inner function crate::HigherOrderUDFImpl::lambda_parameters
using the arguments of this invocation. This expression lambda
variables must be already resolved either by coming from the
default sql planner or by calling Expr::resolve_lambda_variables
or LogicalPlan::resolve_lambda_variables