pub struct WindowFunction {
pub fun: WindowFunctionDefinition,
pub params: WindowFunctionParams,
}Expand description
Window function
Holds the actual function to call WindowFunction as well as its
arguments (args) and the contents of the OVER clause:
PARTITION BYORDER BY- Window frame (e.g.
ROWS 1 PRECEDING AND 1 FOLLOWING)
See ExprFunctionExt for examples of how to create a WindowFunction.
Fields
fun: WindowFunctionDefinitionName of the function
params: WindowFunctionParamsImplementations
Sourceimpl WindowFunction
impl WindowFunction
Sourcepub fn new(
fun: impl Into<WindowFunctionDefinition>,
args: Vec<Expr>,
) -> WindowFunction
pub fn new( fun: impl Into<WindowFunctionDefinition>, args: Vec<Expr>, ) -> WindowFunction
Create a new Window expression with the specified argument an
empty OVER clause
Sourcepub fn simplify(
&self,
) -> Option<Box<dyn Fn(WindowFunction, &SimplifyContext) -> Result<Expr, DataFusionError>>>
pub fn simplify( &self, ) -> Option<Box<dyn Fn(WindowFunction, &SimplifyContext) -> Result<Expr, DataFusionError>>>
Returns this window function’s simplification hook, if any.
See WindowFunctionSimplification for more information