PartitionEvaluatorArgs

Struct PartitionEvaluatorArgs 

pub struct PartitionEvaluatorArgs<'a> { /* private fields */ }
Arguments passed to created user-defined window function state during physical execution.

Implementations

Source

impl<'a> PartitionEvaluatorArgs<'a>

pub fn new( input_exprs: &'a [Arc<dyn PhysicalExpr>], input_fields: &'a [Arc<Field>], is_reversed: bool, ignore_nulls: bool, ) -> PartitionEvaluatorArgs<'a>

Create an instance of PartitionEvaluatorArgs.

Arguments
  • input_exprs - The expressions passed as arguments to the user-defined window function.
  • input_fields - The fields corresponding to the arguments to the user-defined window function.
  • is_reversed - Set to true if and only if the user-defined window function is reversible and is reversed.
  • ignore_nulls - Set to true when IGNORE NULLS is specified.
pub fn input_exprs(&self) -> &'a [Arc<dyn PhysicalExpr>]

Returns the expressions passed as arguments to the user-defined window function.

pub fn input_fields(&self) -> &'a [Arc<Field>]

Returns the FieldRefs corresponding to the input expressions to the user-defined window function.

pub fn is_reversed(&self) -> bool

Returns true when the user-defined window function is reversed, otherwise returns false.

pub fn ignore_nulls(&self) -> bool

Returns true when IGNORE NULLS is specified, otherwise returns false.