LogicalTableSource

Struct LogicalTableSource 

pub struct LogicalTableSource { /* private fields */ }
Basic TableSource implementation intended for use in tests and documentation. It is expected that users will provide their own TableSource implementations or use DataFusion’s DefaultTableSource.

Implementations

Source

impl LogicalTableSource

pub fn new(table_schema: Arc<Schema>) -> LogicalTableSource

Create a new LogicalTableSource

pub fn with_constraints(self, constraints: Constraints) -> LogicalTableSource