pub enum RelationPlanning {
Planned(Box<PlannedRelation>),
Original(Box<TableFactor>),
}Expand description
Result of attempting to plan a relation with extension planners
Variants
Planned(Box<PlannedRelation>)
The relation was successfully planned by an extension planner
Original(Box<TableFactor>)
No extension planner handled the relation, return it for default processing