pub enum FunctionSecurity {
Definer,
Invoker,
}Expand description
Security attribute for functions: SECURITY DEFINER or SECURITY INVOKER.
Variants
Definer
Execute the function with the privileges of the user who defined it.
Invoker
Execute the function with the privileges of the user who invokes it.