pub enum SqlOption {
Clustered(TableOptionsClustered),
Ident(Ident),
KeyValue {
key: Ident,
value: Expr,
},
Partition {
column_name: Ident,
range_direction: Option<PartitionRangeDirection>,
for_values: Vec<Expr>,
},
Comment(CommentDef),
TableSpace(TablespaceOption),
NamedParenthesizedList(NamedParenthesizedList),
}Expand description
SQL option syntax used in table and server definitions.
Variants
Clustered(TableOptionsClustered)
Clustered represents the clustered version of table storage for MSSQL.
Ident(Ident)
Single identifier options, e.g. HEAP for MSSQL.
KeyValue
Any option that consists of a key value pair where the value is an expression. e.g.
WITH(DISTRIBUTION = ROUND_ROBIN)
Partition
One or more table partitions and represents which partition the boundary values belong to, e.g.
PARTITION (id RANGE LEFT FOR VALUES (10, 20, 30, 40))
Fields
range_direction: Option<PartitionRangeDirection>Optional direction for the partition range (LEFT/RIGHT).
Comment(CommentDef)
Comment parameter (supports = and no = syntax)
TableSpace(TablespaceOption)
MySQL TableSpace option https://dev.mysql.com/doc/refman/8.4/en/create-table.html
NamedParenthesizedList(NamedParenthesizedList)
An option representing a key value pair, where the value is a parenthesized list and with an optional name e.g.
UNION = (tbl_name[,tbl_name]…) https://dev.mysql.com/doc/refman/8.4/en/create-table.html ENGINE = ReplicatedMergeTree(‘/table_name’,‘{replica}’, ver) https://clickhouse.com/docs/engines/table-engines/mergetree-family/replication ENGINE = SummingMergeTree([columns]) https://clickhouse.com/docs/engines/table-engines/mergetree-family/summingmergetree