pub enum Subscript {
Index {
index: Expr,
},
Slice {
lower_bound: Option<Expr>,
upper_bound: Option<Expr>,
stride: Option<Expr>,
},
}Expand description
The contents inside the [ and ] in a subscript expression.
Variants
Index
Accesses the element of the array at the given index.
Slice
Accesses a slice of an array on PostgreSQL, e.g.
=> select (array[1,2,3,4,5,6])[2:5];
-----------
{2,3,4,5}The lower and/or upper bound can be omitted to slice from the start or end of the array respectively.
See https://www.postgresql.org/docs/current/arrays.html#ARRAYS-ACCESSING.
Also supports an optional “stride” as the last element (this is not supported by postgres), e.g.
=> select (array[1,2,3,4,5,6])[1:6:2];
-----------
{1,3,5}Trait Implementations
impl Eq for Subscript
Sourceimpl Ord for Subscript
impl Ord for Subscript
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Subscript
impl PartialOrd for Subscript
impl StructuralPartialEq for Subscript
Sourceimpl VisitMut for Subscript
impl VisitMut for Subscript
Sourcefn visit<V>(&mut self, visitor: &mut V) -> ControlFlow<<V as VisitorMut>::Break>where
V: VisitorMut,
fn visit<V>(&mut self, visitor: &mut V) -> ControlFlow<<V as VisitorMut>::Break>where
V: VisitorMut,
Mutably visit this node with the provided
VisitorMut. Read moreAuto Trait Implementations
impl Freeze for Subscript
impl RefUnwindSafe for Subscript
impl Send for Subscript
impl Sync for Subscript
impl Unpin for Subscript
impl UnsafeUnpin for Subscript
impl UnwindSafe for Subscript