AttachedToken

pub struct AttachedToken(pub TokenWithSpan);
A wrapper over TokenWithSpans that ignores the token and source location in comparisons and hashing.

This type is used when the token and location is not relevant for semantics, but is still needed for accurate source location tracking, for example, in the nodes in the ast module.

Note: All AttachedTokens are equal.

Examples

Same token, different location are equal

// commas @ line 1, column 10
let tok1 = TokenWithLocation::new(
  Token::Comma,
  Span::new(Location::new(1, 10), Location::new(1, 11)),
);
// commas @ line 2, column 20
let tok2 = TokenWithLocation::new(
  Token::Comma,
  Span::new(Location::new(2, 20), Location::new(2, 21)),
);

assert_ne!(tok1, tok2); // token with locations are *not* equal
assert_eq!(AttachedToken(tok1), AttachedToken(tok2)); // attached tokens are

Different token, different location are equal 🤯

// commas @ line 1, column 10
let tok1 = TokenWithLocation::new(
  Token::Comma,
  Span::new(Location::new(1, 10), Location::new(1, 11)),
);
// period @ line 2, column 20
let tok2 = TokenWithLocation::new(
 Token::Period,
  Span::new(Location::new(2, 10), Location::new(2, 21)),
);

assert_ne!(tok1, tok2); // token with locations are *not* equal
assert_eq!(AttachedToken(tok1), AttachedToken(tok2)); // attached tokens are

// period @ line 2, column 20

Tuple Fields

0: TokenWithSpan

Implementations

Source

impl AttachedToken

pub fn empty() -> AttachedToken

Return a new Empty AttachedToken