Function

Struct Function 

pub struct Function {
    pub name: ObjectName,
    pub uses_odbc_syntax: bool,
    pub parameters: FunctionArguments,
    pub args: FunctionArguments,
    pub filter: Option<Box<Expr>>,
    pub null_treatment: Option<NullTreatment>,
    pub over: Option<WindowType>,
    pub within_group: Vec<OrderByExpr>,
}
A function call

Fields

name: ObjectName

The function name (may be qualified).

uses_odbc_syntax: bool

Flags whether this function call uses the ODBC syntax.

Example:

SELECT {fn CONCAT('foo', 'bar')}
parameters: FunctionArguments

The parameters to the function, including any options specified within the delimiting parentheses.

Example:

HISTOGRAM(0.5, 0.6)(x, y)

ClickHouse

args: FunctionArguments

The arguments to the function, including any options specified within the delimiting parentheses.

filter: Option<Box<Expr>>

e.g. x > 5 in COUNT(x) FILTER (WHERE x > 5)

null_treatment: Option<NullTreatment>

Indicates how NULLs should be handled in the calculation.

Example:

FIRST_VALUE( <expr> ) [ { IGNORE | RESPECT } NULLS ] OVER ...

Snowflake

over: Option<WindowType>

The OVER clause, indicating a window function call.

within_group: Vec<OrderByExpr>

A clause used with certain aggregate functions to control the ordering within grouped sets before the function is applied.

Syntax:

<aggregate_function>(expression) WITHIN GROUP (ORDER BY key [ASC | DESC], ...)