pub struct CreateFunction {
pub or_replace: bool,
pub temporary: bool,
pub name: String,
pub args: Option<Vec<OperateFunctionArg>>,
pub return_type: Option<DataType>,
pub params: CreateFunctionBody,
pub schema: Arc<DFSchema>,
}Expand description
Arguments passed to the CREATE FUNCTION statement
These statements are turned into executable functions using FunctionFactory
Notes
This structure purposely mirrors the structure in sqlparser’s
sqlparser::ast::Statement::CreateFunction, but does not use it directly
to avoid a dependency on sqlparser in the core crate.
Fields
or_replace: booltemporary: boolname: Stringargs: Option<Vec<OperateFunctionArg>>return_type: Option<DataType>params: CreateFunctionBodyschema: Arc<DFSchema>Dummy schema