HigherOrderReturnFieldArgs

Struct HigherOrderReturnFieldArgs 

pub struct HigherOrderReturnFieldArgs<'a> {
    pub arg_fields: &'a [ValueOrLambda<Arc<Field>, Arc<Field>>],
    pub scalar_arguments: &'a [Option<&'a ScalarValue>],
}
Information about arguments passed to the function

This structure contains metadata about how the function was called such as the type of the arguments, any scalar arguments and if the arguments can (ever) be null

See HigherOrderUDFImpl::return_field_from_args for more information

Fields

arg_fields: &'a [ValueOrLambda<Arc<Field>, Arc<Field>>]

The data types of the arguments to the function

If argument i to the function is a lambda, it will be the field of the result of the lambda if evaluated with the parameters returned from HigherOrderUDFImpl::lambda_parameters

For example, with array_transform([1], v -> v == 5) this field will be

[
    ValueOrLambda::Value(Field::new("", DataType::new_list(DataType::Int32, true), true)),
    ValueOrLambda::Lambda(Field::new("", DataType::Boolean, true))
]
scalar_arguments: &'a [Option<&'a ScalarValue>]

Is argument i to the function a scalar (constant)?

If the argument i is not a scalar, it will be None

For example, if a function is called like array_transform([1], v -> v == 5) this field will be [Some(ScalarValue::List(...), None]