pub struct HigherOrderSignature {
pub type_signature: HigherOrderTypeSignature,
pub volatility: Volatility,
pub lambda_parameters_max_iterations: usize,
}Expand description
Provides information necessary for calling a higher order function.
-
HigherOrderTypeSignaturedefines the argument types that a function has implementations for. -
Volatilitydefines how the output of the function changes with the input.
Fields
type_signature: HigherOrderTypeSignatureThe data types that the function accepts. See HigherOrderTypeSignature for more information.
volatility: VolatilityThe volatility of the function. See Volatility for more information.
lambda_parameters_max_iterations: usizeThe max number of times to call HigherOrderUDFImpl::lambda_parameters before raising an error. Used to guard against implementations that causes an infinite loop by endlessly returning LambdaParametersProgress::Partial. Defaults to 256
Implementations
Sourceimpl HigherOrderSignature
impl HigherOrderSignature
Sourcepub fn new(
type_signature: HigherOrderTypeSignature,
volatility: Volatility,
) -> HigherOrderSignature
pub fn new( type_signature: HigherOrderTypeSignature, volatility: Volatility, ) -> HigherOrderSignature
Creates a new HigherOrderSignature from a given type signature and volatility.
Sourcepub fn user_defined(volatility: Volatility) -> HigherOrderSignature
pub fn user_defined(volatility: Volatility) -> HigherOrderSignature
User-defined coercion rules for the function.
Sourcepub fn variadic_any(volatility: Volatility) -> HigherOrderSignature
pub fn variadic_any(volatility: Volatility) -> HigherOrderSignature
An arbitrary number of lambdas or arguments of any type.
Sourcepub fn any(arg_count: usize, volatility: Volatility) -> HigherOrderSignature
pub fn any(arg_count: usize, volatility: Volatility) -> HigherOrderSignature
A specified number of arguments of any type
Sourcepub fn exact(
args: Vec<ValueOrLambda<(), ()>>,
volatility: Volatility,
) -> HigherOrderSignature
pub fn exact( args: Vec<ValueOrLambda<(), ()>>, volatility: Volatility, ) -> HigherOrderSignature
Exactly the specified arguments in the given order, with arbitrary types.
DataFusion will call HigherOrderUDFImpl::coerce_value_types to prepare the value
argument types.
Example
A function that takes one value argument followed by one lambda:
let sig = HigherOrderSignature::exact(
vec![ValueOrLambda::Value(()), ValueOrLambda::Lambda(())],
Volatility::Immutable,
);Trait Implementations
Sourceimpl Clone for HigherOrderSignature
impl Clone for HigherOrderSignature
Sourcefn clone(&self) -> HigherOrderSignature
fn clone(&self) -> HigherOrderSignature
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for HigherOrderSignature
impl Debug for HigherOrderSignature
impl Eq for HigherOrderSignature
Sourceimpl Hash for HigherOrderSignature
impl Hash for HigherOrderSignature
Sourceimpl PartialEq for HigherOrderSignature
impl PartialEq for HigherOrderSignature
Sourcefn eq(&self, other: &HigherOrderSignature) -> bool
fn eq(&self, other: &HigherOrderSignature) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for HigherOrderSignature
impl PartialOrd for HigherOrderSignature
impl StructuralPartialEq for HigherOrderSignature