ReturnFieldArgs

Struct ReturnFieldArgs 

pub struct ReturnFieldArgs<'a> {
    pub arg_fields: &'a [Arc<Field>],
    pub scalar_arguments: &'a [Option<&'a ScalarValue>],
}
Information about arguments passed to the function

This structure contains metadata about how the function was called such as the type of the arguments, any scalar arguments and if the arguments can (ever) be null

See ScalarUDFImpl::return_field_from_args for more information

Fields

arg_fields: &'a [Arc<Field>]

The data types of the arguments to the function

scalar_arguments: &'a [Option<&'a ScalarValue>]

Is argument i to the function a scalar (constant)?

If the argument i is not a scalar, it will be None

For example, if a function is called like my_function(column_a, 5) this field will be [None, Some(ScalarValue::Int32(Some(5)))]