pub struct TableScan {
pub table_name: TableReference,
pub source: Arc<dyn TableSource>,
pub projection: Option<Vec<usize>>,
pub projected_schema: Arc<DFSchema>,
pub filters: Vec<Expr>,
pub fetch: Option<usize>,
}Expand description
Produces rows from a table provider by reference or from the context
Fields
table_name: TableReferenceThe name of the table
source: Arc<dyn TableSource>The source of the table
projection: Option<Vec<usize>>Optional column indices to use as a projection
projected_schema: Arc<DFSchema>The schema description of the output
filters: Vec<Expr>Optional expressions to be used as filters by the table provider
fetch: Option<usize>Optional number of rows to read
Implementations