DFParser

Struct DFParser 

pub struct DFParser<'a> {
    pub parser: Parser<'a>,
    /* private fields */
}
DataFusion SQL Parser based on sqlparser

Parses DataFusion’s SQL dialect, often delegating to sqlparser’s Parser.

DataFusion mostly follows existing SQL dialects via sqlparser. However, certain statements such as COPY and CREATE EXTERNAL TABLE have special syntax in DataFusion. See Statement for a list of this special syntax

Fields

parser: Parser<'a>

Implementations

Source

impl<'a> DFParser<'a>

pub fn new(sql: &'a str) -> Result<DFParser<'a>, DataFusionError>

👎Deprecated since 46.0.0:

DFParserBuilder

pub fn new_with_dialect( sql: &'a str, dialect: &'a (dyn Dialect + 'static), ) -> Result<DFParser<'a>, DataFusionError>

👎Deprecated since 46.0.0:

DFParserBuilder

pub fn parse_sql(sql: &'a str) -> Result<VecDeque<Statement>, DataFusionError>

Parse a sql string into one or Statements using the GenericDialect.

pub fn parse_sql_with_dialect( sql: &str, dialect: &(dyn Dialect + 'static), ) -> Result<VecDeque<Statement>, DataFusionError>

Parse a SQL string and produce one or more Statements with with the specified dialect.

pub fn parse_sql_into_expr(sql: &str) -> Result<ExprWithAlias, DataFusionError>

pub fn parse_sql_into_expr_with_dialect( sql: &str, dialect: &(dyn Dialect + 'static), ) -> Result<ExprWithAlias, DataFusionError>

pub fn parse_statements( &mut self, ) -> Result<VecDeque<Statement>, DataFusionError>

Parse a sql string into one or Statements

pub fn parse_statement(&mut self) -> Result<Statement, DataFusionError>

Parse a new expression

pub fn parse_expr(&mut self) -> Result<ExprWithAlias, DataFusionError>

pub fn parse_into_expr(&mut self) -> Result<ExprWithAlias, DataFusionError>

Parses the entire SQL string into an expression.

In contrast to DFParser::parse_expr, this function will report an error if the input contains any trailing, unparsed tokens.

pub fn parse_copy(&mut self) -> Result<Statement, DataFusionError>

Parse a SQL COPY TO statement

pub fn parse_option_key(&mut self) -> Result<String, DataFusionError>

Parse the next token as a key name for an option list

Note this is different than parse_literal_string because it allows keywords as well as other non words

pub fn parse_option_value(&mut self) -> Result<Value, DataFusionError>

Parse the next token as a value for an option list

Note this is different than parse_value as it allows any word or keyword in this location.

pub fn parse_explain(&mut self) -> Result<Statement, DataFusionError>

Parse a SQL EXPLAIN

pub fn parse_reset(&mut self) -> Result<Statement, DataFusionError>

Parse a SQL RESET

pub fn parse_explain_format( &mut self, ) -> Result<Option<String>, DataFusionError>

pub fn parse_create(&mut self) -> Result<Statement, DataFusionError>

Parse a SQL CREATE statement handling CREATE EXTERNAL TABLE

pub fn parse_order_by_exprs( &mut self, ) -> Result<Vec<OrderByExpr>, DataFusionError>

Parse the ordering clause of a CREATE EXTERNAL TABLE SQL statement

pub fn parse_order_by_expr(&mut self) -> Result<OrderByExpr, DataFusionError>

Parse an ORDER BY sub-expression optionally followed by ASC or DESC.