pub struct ConstraintUsingIndex {
pub name: Option<Ident>,
pub index_name: Ident,
pub characteristics: Option<ConstraintCharacteristics>,
}Expand description
PostgreSQL constraint that promotes an existing unique index to a table constraint.
[ CONSTRAINT constraint_name ] { UNIQUE | PRIMARY KEY } USING INDEX index_name [ DEFERRABLE | NOT DEFERRABLE ] [ INITIALLY DEFERRED | INITIALLY IMMEDIATE ]
See https://www.postgresql.org/docs/current/sql-altertable.html
Fields
name: Option<Ident>Optional constraint name.
index_name: IdentThe name of the existing unique index to promote.
characteristics: Option<ConstraintCharacteristics>Optional characteristics like DEFERRABLE.
Implementations