pub struct Ident {
pub value: String,
pub quote_style: Option<char>,
pub span: Span,
}Expand description
An identifier, decomposed into its value or character data and the quote style.
Fields
value: StringThe value of the identifier without quotes.
quote_style: Option<char>The starting quote if any. Valid quote characters are the single quote, double quote, backtick, and opening square bracket.
span: SpanThe span of the identifier in the original SQL string.
Implementations
Sourceimpl Ident
impl Ident
Sourcepub fn new<S>(value: S) -> Ident
pub fn new<S>(value: S) -> Ident
Create a new identifier with the given value and no quotes and an empty span.
Sourcepub fn with_quote<S>(quote: char, value: S) -> Ident
pub fn with_quote<S>(quote: char, value: S) -> Ident
Create a new quoted identifier with the given quote and value. This function panics if the given quote is not a valid quote character.