Word

pub struct Word {
    pub value: String,
    pub quote_style: Option<char>,
    pub keyword: Keyword,
}
A keyword (like SELECT) or an optionally quoted SQL identifier

Fields

value: String

The value of the token, without the enclosing quotes, and with the escape sequences (if any) processed (TODO: escapes are not handled)

quote_style: Option<char>

An identifier can be “quoted” (<delimited identifier> in ANSI parlance). The standard and most implementations allow using double quotes for this, but some implementations support other quoting styles as well (e.g. [MS SQL])

keyword: Keyword

If the word was not quoted and it matched one of the known keywords, this will have one of the values from dialect::keywords, otherwise empty

Implementations

Source

impl Word

pub fn to_ident(&self, span: Span) -> Ident

Convert a reference to this word into an Ident by cloning the value.

Use this method when you need to keep the original Word around. If you can consume the Word, prefer into_ident instead to avoid cloning.

pub fn into_ident(self, span: Span) -> Ident

Convert this word into an Ident identifier, consuming the Word.

This avoids cloning the string value. If you need to keep the original Word, use to_ident instead.