pub struct PyDropCatalogSchema { /* private fields */ }Trait Implementations
Sourceimpl Clone for PyDropCatalogSchema
impl Clone for PyDropCatalogSchema
Sourcefn clone(&self) -> PyDropCatalogSchema
fn clone(&self) -> PyDropCatalogSchema
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl DerefToPyAny for PyDropCatalogSchema
Sourceimpl Display for PyDropCatalogSchema
impl Display for PyDropCatalogSchema
Sourceimpl From<DropCatalogSchema> for PyDropCatalogSchema
impl From<DropCatalogSchema> for PyDropCatalogSchema
Sourcefn from(drop: DropCatalogSchema) -> PyDropCatalogSchema
fn from(drop: DropCatalogSchema) -> PyDropCatalogSchema
Converts to this type from the input type.
Sourceimpl From<PyDropCatalogSchema> for DropCatalogSchema
impl From<PyDropCatalogSchema> for DropCatalogSchema
Sourcefn from(drop: PyDropCatalogSchema) -> Self
fn from(drop: PyDropCatalogSchema) -> Self
Converts to this type from the input type.
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for PyDropCatalogSchemawhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for PyDropCatalogSchemawhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for PyDropCatalogSchema
impl<'py> IntoPyObject<'py> for PyDropCatalogSchema
Sourcetype Target = PyDropCatalogSchema
type Target = PyDropCatalogSchema
The Python output type
Sourcetype Output = Bound<'py, <PyDropCatalogSchema as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyDropCatalogSchema as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl LogicalNode for PyDropCatalogSchema
impl LogicalNode for PyDropCatalogSchema
Sourceimpl PyClass for PyDropCatalogSchema
impl PyClass for PyDropCatalogSchema
Sourceimpl PyClassBaseType for PyDropCatalogSchema
impl PyClassBaseType for PyDropCatalogSchema
type LayoutAsBase = <PyDropCatalogSchema as PyClassImpl>::Layout
type BaseNativeType = <PyDropCatalogSchema as PyClassImpl>::BaseNativeType
type Initializer = PyClassInitializer<PyDropCatalogSchema>
type PyClassMutability = <PyDropCatalogSchema as PyClassImpl>::PyClassMutability
Sourcetype Layout<T: PyClassImpl> = <<PyDropCatalogSchema as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
type Layout<T: PyClassImpl> = <<PyDropCatalogSchema as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
The type of object layout to use for ancestors or descendants of this type.
Sourceimpl PyClassImpl for PyDropCatalogSchema
impl PyClassImpl for PyDropCatalogSchema
Sourceconst IS_BASETYPE: bool = true
const IS_BASETYPE: bool = true
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyDropCatalogSchema as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyDropCatalogSchema>
type Layout = <<PyDropCatalogSchema as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyDropCatalogSchema>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for PyDropCatalogSchema
impl PyClassNewTextSignature for PyDropCatalogSchema
const TEXT_SIGNATURE: &'static str = "(name, schema, if_exists, cascade)"
Sourceimpl PyMethods<PyDropCatalogSchema> for PyClassImplCollector<PyDropCatalogSchema>
impl PyMethods<PyDropCatalogSchema> for PyClassImplCollector<PyDropCatalogSchema>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyDropCatalogSchema
impl PyTypeInfo for PyDropCatalogSchema
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.