pub struct PyPartitioning { /* private fields */ }Trait Implementations
Sourceimpl Clone for PyPartitioning
impl Clone for PyPartitioning
Sourcefn clone(&self) -> PyPartitioning
fn clone(&self) -> PyPartitioning
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl DerefToPyAny for PyPartitioning
Sourceimpl From<Partitioning> for PyPartitioning
impl From<Partitioning> for PyPartitioning
Sourcefn from(partitioning: Partitioning) -> Self
fn from(partitioning: Partitioning) -> Self
Converts to this type from the input type.
Sourceimpl From<PyPartitioning> for Partitioning
impl From<PyPartitioning> for Partitioning
Sourcefn from(partitioning: PyPartitioning) -> Self
fn from(partitioning: PyPartitioning) -> Self
Converts to this type from the input type.
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for PyPartitioningwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for PyPartitioningwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for PyPartitioning
impl<'py> IntoPyObject<'py> for PyPartitioning
Sourcetype Target = PyPartitioning
type Target = PyPartitioning
The Python output type
Sourcetype Output = Bound<'py, <PyPartitioning as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyPartitioning as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyPartitioning
impl PyClass for PyPartitioning
Sourceimpl PyClassBaseType for PyPartitioning
impl PyClassBaseType for PyPartitioning
type LayoutAsBase = <PyPartitioning as PyClassImpl>::Layout
type BaseNativeType = <PyPartitioning as PyClassImpl>::BaseNativeType
type Initializer = PyClassInitializer<PyPartitioning>
type PyClassMutability = <PyPartitioning as PyClassImpl>::PyClassMutability
Sourcetype Layout<T: PyClassImpl> = <<PyPartitioning as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
type Layout<T: PyClassImpl> = <<PyPartitioning as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
The type of object layout to use for ancestors or descendants of this type.
Sourceimpl PyClassImpl for PyPartitioning
impl PyClassImpl for PyPartitioning
Sourceconst IS_BASETYPE: bool = true
const IS_BASETYPE: bool = true
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyPartitioning as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyPartitioning>
type Layout = <<PyPartitioning as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyPartitioning>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyTypeInfo for PyPartitioning
impl PyTypeInfo for PyPartitioning
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.