pub struct PySubquery { /* private fields */ }Trait Implementations
Sourceimpl Clone for PySubquery
impl Clone for PySubquery
Sourcefn clone(&self) -> PySubquery
fn clone(&self) -> PySubquery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl DerefToPyAny for PySubquery
Sourceimpl Display for PySubquery
impl Display for PySubquery
Sourceimpl From<PySubquery> for Subquery
impl From<PySubquery> for Subquery
Sourcefn from(subquery: PySubquery) -> Self
fn from(subquery: PySubquery) -> Self
Converts to this type from the input type.
Sourceimpl From<Subquery> for PySubquery
impl From<Subquery> for PySubquery
Sourcefn from(subquery: Subquery) -> PySubquery
fn from(subquery: Subquery) -> PySubquery
Converts to this type from the input type.
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for PySubquerywhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for PySubquerywhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for PySubquery
impl<'py> IntoPyObject<'py> for PySubquery
Sourcetype Target = PySubquery
type Target = PySubquery
The Python output type
Sourcetype Output = Bound<'py, <PySubquery as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PySubquery as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl LogicalNode for PySubquery
impl LogicalNode for PySubquery
Sourceimpl PyClass for PySubquery
impl PyClass for PySubquery
Sourceimpl PyClassBaseType for PySubquery
impl PyClassBaseType for PySubquery
type LayoutAsBase = <PySubquery as PyClassImpl>::Layout
type BaseNativeType = <PySubquery as PyClassImpl>::BaseNativeType
type Initializer = PyClassInitializer<PySubquery>
type PyClassMutability = <PySubquery as PyClassImpl>::PyClassMutability
Sourcetype Layout<T: PyClassImpl> = <<PySubquery as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
type Layout<T: PyClassImpl> = <<PySubquery as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
The type of object layout to use for ancestors or descendants of this type.
Sourceimpl PyClassImpl for PySubquery
impl PyClassImpl for PySubquery
Sourceconst IS_BASETYPE: bool = true
const IS_BASETYPE: bool = true
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PySubquery as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PySubquery>
type Layout = <<PySubquery as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PySubquery>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyMethods<PySubquery> for PyClassImplCollector<PySubquery>
impl PyMethods<PySubquery> for PyClassImplCollector<PySubquery>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PySubquery
impl PyTypeInfo for PySubquery
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.