pub struct PySubqueryAlias { /* private fields */ }Trait Implementations
Sourceimpl Clone for PySubqueryAlias
impl Clone for PySubqueryAlias
Sourcefn clone(&self) -> PySubqueryAlias
fn clone(&self) -> PySubqueryAlias
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl DerefToPyAny for PySubqueryAlias
Sourceimpl Display for PySubqueryAlias
impl Display for PySubqueryAlias
Sourceimpl From<PySubqueryAlias> for SubqueryAlias
impl From<PySubqueryAlias> for SubqueryAlias
Sourcefn from(subquery_alias: PySubqueryAlias) -> Self
fn from(subquery_alias: PySubqueryAlias) -> Self
Converts to this type from the input type.
Sourceimpl From<SubqueryAlias> for PySubqueryAlias
impl From<SubqueryAlias> for PySubqueryAlias
Sourcefn from(subquery_alias: SubqueryAlias) -> PySubqueryAlias
fn from(subquery_alias: SubqueryAlias) -> PySubqueryAlias
Converts to this type from the input type.
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for PySubqueryAliaswhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for PySubqueryAliaswhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for PySubqueryAlias
impl<'py> IntoPyObject<'py> for PySubqueryAlias
Sourcetype Target = PySubqueryAlias
type Target = PySubqueryAlias
The Python output type
Sourcetype Output = Bound<'py, <PySubqueryAlias as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PySubqueryAlias as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl LogicalNode for PySubqueryAlias
impl LogicalNode for PySubqueryAlias
Sourceimpl PyClass for PySubqueryAlias
impl PyClass for PySubqueryAlias
Sourceimpl PyClassBaseType for PySubqueryAlias
impl PyClassBaseType for PySubqueryAlias
type LayoutAsBase = <PySubqueryAlias as PyClassImpl>::Layout
type BaseNativeType = <PySubqueryAlias as PyClassImpl>::BaseNativeType
type Initializer = PyClassInitializer<PySubqueryAlias>
type PyClassMutability = <PySubqueryAlias as PyClassImpl>::PyClassMutability
Sourcetype Layout<T: PyClassImpl> = <<PySubqueryAlias as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
type Layout<T: PyClassImpl> = <<PySubqueryAlias as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
The type of object layout to use for ancestors or descendants of this type.
Sourceimpl PyClassImpl for PySubqueryAlias
impl PyClassImpl for PySubqueryAlias
Sourceconst IS_BASETYPE: bool = true
const IS_BASETYPE: bool = true
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PySubqueryAlias as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PySubqueryAlias>
type Layout = <<PySubqueryAlias as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PySubqueryAlias>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyMethods<PySubqueryAlias> for PyClassImplCollector<PySubqueryAlias>
impl PyMethods<PySubqueryAlias> for PyClassImplCollector<PySubqueryAlias>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PySubqueryAlias
impl PyTypeInfo for PySubqueryAlias
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.