Module simplify_literal

Module simplify_literal 

Parses and simplifies an expression to a literal of a given type.

This module provides functionality to parse and simplify static expressions used in SQL constructs like FROM TABLE SAMPLE (10 + 50 * 2). If they are required in a planning (not an execution) phase, they need to be reduced to literals of a given type.

Functions

parse_literal
Parse and simplifies an expression to a numeric literal, corresponding to an arrow primitive type T (for example, Float64Type).