Module utils

Module utils 

Utility functions leveraged by the query optimizer rules

Structs

NamePreserver
Handles ensuring the name of rewritten expressions is not changed.

Functions

evaluates_to_null
Determines if an expression will always evaluate to null. c0 + 8 return true c0 IS NULL return false CASE WHEN c0 > 1 then 0 else 1 return false
is_restrict_null_predicate
Determine whether a predicate can restrict NULLs. e.g. c0 > 8 return true; c0 IS NULL return false.
log_plan
Log the plan in debug/tracing mode after some part of the optimizer runs