pub struct PyDataType {
pub data_type: DataType,
}Expand description
PyO3 requires that objects passed between Rust and Python implement the trait PyClass
Since DataType exists in another package we cannot make that happen here so we wrap
DataType as PyDataType This exists solely to satisfy those constraints.
Fields
data_type: DataTypeImplementations
Sourceimpl PyDataType
impl PyDataType
Sourcepub fn py_map_from_arrow_type_str(
arrow_str_type: String,
) -> PyResult<PyDataType>
pub fn py_map_from_arrow_type_str( arrow_str_type: String, ) -> PyResult<PyDataType>
There are situations when obtaining dtypes on the Python side where the Arrow type is presented as a String rather than an actual DataType. This function is used to convert that String to a DataType for the Python side to use.