pub struct DecoderContext { /* private fields */ }Expand description
Context for decoder creation, containing configuration.
This context is passed through the decoder creation process and contains all the configuration needed to create decoders recursively.
Implementations
Sourceimpl DecoderContext
impl DecoderContext
Sourcepub fn coerce_primitive(&self) -> bool
pub fn coerce_primitive(&self) -> bool
Returns whether to coerce primitive types (e.g., number to string)
Sourcepub fn strict_mode(&self) -> bool
pub fn strict_mode(&self) -> bool
Returns whether to validate struct fields strictly
Sourcepub fn struct_mode(&self) -> StructMode
pub fn struct_mode(&self) -> StructMode
Returns how to decode struct fields