CompositePruningStatistics

Struct CompositePruningStatistics 

pub struct CompositePruningStatistics {
    pub statistics: Vec<Box<dyn PruningStatistics>>,
}
๐Ÿ‘ŽDeprecated since 52.0.0: This struct is no longer used internally. It may be removed in 58.0.0 or 6 months after 52.0.0 is released, whichever comes first. Please open an issue if you have a use case for it.
Combine multiple PruningStatistics into a single CompositePruningStatistics. This can be used to combine statistics from different sources, for example partition values and file statistics. This allows pruning with filters that depend on multiple sources of statistics, such as WHERE partition_col = data_col. This is done by iterating over the statistics and returning the first one that has information for the requested column. If multiple statistics have information for the same column, the first one is returned without any regard for completeness or accuracy. That is: if the first statistics has information for a column, even if it is incomplete, that is returned even if a later statistics has more complete information.

Fields

statistics: Vec<Box<dyn PruningStatistics>>
๐Ÿ‘ŽDeprecated since 52.0.0: This struct is no longer used internally. It may be removed in 58.0.0 or 6 months after 52.0.0 is released, whichever comes first. Please open an issue if you have a use case for it.

Implementations