SimplifyContext

Struct SimplifyContext 

pub struct SimplifyContext { /* private fields */ }
Provides simplification information based on schema, query execution time, and configuration options.

Example

See the simplify_demo in the expr_api example

Implementations

Source

impl SimplifyContext

pub fn builder() -> SimplifyContextBuilder

Returns a builder for SimplifyContext.

pub fn with_config_options( self, config_options: Arc<ConfigOptions>, ) -> SimplifyContext

👎Deprecated since 54.0.0:

Use SimplifyContextBuilder if you intend to use non-default values.

Set the ConfigOptions for this context

pub fn with_schema(self, schema: Arc<DFSchema>) -> SimplifyContext

👎Deprecated since 54.0.0:

Use SimplifyContextBuilder if you intend to use non-default values.

Set the schema for this context

pub fn with_query_execution_start_time( self, query_execution_start_time: Option<DateTime<Utc>>, ) -> SimplifyContext

👎Deprecated since 54.0.0:

Use SimplifyContextBuilder if you intend to use non-default values.

Set the query execution start time

pub fn with_current_time(self) -> SimplifyContext

👎Deprecated since 54.0.0:

Use SimplifyContextBuilder if you intend to use non-default values.

Set the query execution start to the current time

pub fn schema(&self) -> &Arc<DFSchema>

Returns the schema

pub fn is_boolean_type(&self, expr: &Expr) -> Result<bool, DataFusionError>

Returns true if this Expr has boolean type

pub fn nullable(&self, expr: &Expr) -> Result<bool, DataFusionError>

Returns true if expr is nullable

pub fn get_data_type(&self, expr: &Expr) -> Result<DataType, DataFusionError>

Returns data type of this expr needed for determining optimized int type of a value

pub fn query_execution_start_time(&self) -> Option<DateTime<Utc>>

Returns the time at which the query execution started. If None, time-dependent functions like now() will not be simplified.

pub fn config_options(&self) -> &Arc<ConfigOptions>

Returns the configuration options for the session.