SelectModifiers

Struct SelectModifiers 

pub struct SelectModifiers {
    pub high_priority: bool,
    pub straight_join: bool,
    pub sql_small_result: bool,
    pub sql_big_result: bool,
    pub sql_buffer_result: bool,
    pub sql_no_cache: bool,
    pub sql_calc_found_rows: bool,
}
MySQL-specific SELECT modifiers that appear after the SELECT keyword.

These modifiers affect query execution and optimization. They can appear in any order after SELECT and before the column list, can be repeated, and can be interleaved with DISTINCT/DISTINCTROW/ALL:

SELECT
    [ALL | DISTINCT | DISTINCTROW]
    [HIGH_PRIORITY]
    [STRAIGHT_JOIN]
    [SQL_SMALL_RESULT] [SQL_BIG_RESULT] [SQL_BUFFER_RESULT]
    [SQL_NO_CACHE] [SQL_CALC_FOUND_ROWS]
    select_expr [, select_expr] ...

See MySQL SELECT.

Fields

high_priority: bool

HIGH_PRIORITY gives the SELECT higher priority than statements that update a table.

https://dev.mysql.com/doc/refman/8.4/en/select.html

straight_join: bool

STRAIGHT_JOIN forces the optimizer to join tables in the order listed in the FROM clause.

https://dev.mysql.com/doc/refman/8.4/en/select.html

sql_small_result: bool

SQL_SMALL_RESULT hints that the result set is small, using in-memory temp tables.

https://dev.mysql.com/doc/refman/8.4/en/select.html

sql_big_result: bool

SQL_BIG_RESULT hints that the result set is large, using disk-based temp tables.

https://dev.mysql.com/doc/refman/8.4/en/select.html

sql_buffer_result: bool

SQL_BUFFER_RESULT forces the result to be put into a temporary table to release locks early.

https://dev.mysql.com/doc/refman/8.4/en/select.html

sql_no_cache: bool

SQL_NO_CACHE tells MySQL not to cache the query result. (Deprecated in 8.4+.)

https://dev.mysql.com/doc/refman/8.4/en/select.html

sql_calc_found_rows: bool

SQL_CALC_FOUND_ROWS tells MySQL to calculate the total number of rows. (Deprecated in 8.0.17+.)

Implementations

Source

impl SelectModifiers

pub fn is_any_set(&self) -> bool

Returns true if any of the modifiers are set.