pub struct TriggerExecBody {
pub exec_type: TriggerExecBodyType,
pub func_desc: FunctionDesc,
}Expand description
This keyword immediately precedes the declaration of one or two relation names that provide access to the transition relations of the triggering statement
Fields
exec_type: TriggerExecBodyTypeWhether the body is a FUNCTION or PROCEDURE invocation.
func_desc: FunctionDescDescription of the function/procedure to execute.