pub struct Word {
pub value: String,
pub quote_style: Option<char>,
pub keyword: Keyword,
}Expand description
A keyword (like SELECT) or an optionally quoted SQL identifier
Fields
value: StringThe value of the token, without the enclosing quotes, and with the escape sequences (if any) processed (TODO: escapes are not handled)
quote_style: Option<char>An identifier can be “quoted” (<delimited identifier> in ANSI parlance). The standard and most implementations allow using double quotes for this, but some implementations support other quoting styles as well (e.g. [MS SQL])
keyword: KeywordIf the word was not quoted and it matched one of the known keywords, this will have one of the values from dialect::keywords, otherwise empty
Implementations