pub struct SelectBuilder { /* private fields */ }Implementations
Sourceimpl SelectBuilder
impl SelectBuilder
pub fn distinct(&mut self, value: Option<Distinct>) -> &mut SelectBuilder
pub fn top(&mut self, value: Option<Top>) -> &mut SelectBuilder
pub fn projection(&mut self, value: Vec<SelectItem>) -> &mut SelectBuilder
pub fn pop_projections(&mut self) -> Vec<SelectItem>
Sourcepub fn already_projected(&self) -> bool
pub fn already_projected(&self) -> bool
Returns true if a projection has been explicitly set via projection().
This method is used to determine whether the SELECT clause has already been
defined, which helps avoid creating duplicate projection nodes during query
unparsing. It returns true for both empty and non-empty projections.
Returns
trueifprojection()has been called (regardless of whether it was empty or not)falseif no projection has been set yet
Example
let mut builder = SelectBuilder::default();
assert!(!builder.already_projected());
builder.projection(vec![]);
assert!(builder.already_projected()); // true even for empty projection
builder.projection(vec![SelectItem::Wildcard(...)]);
assert!(builder.already_projected()); // true for non-empty projectionpub fn into(&mut self, value: Option<SelectInto>) -> &mut SelectBuilder
pub fn from(&mut self, value: Vec<TableWithJoinsBuilder>) -> &mut SelectBuilder
pub fn push_from(&mut self, value: TableWithJoinsBuilder) -> &mut SelectBuilder
pub fn pop_from(&mut self) -> Option<TableWithJoinsBuilder>
pub fn lateral_views(&mut self, value: Vec<LateralView>) -> &mut SelectBuilder
Sourcepub fn replace_mark(
&mut self,
existing_expr: &Expr,
value: &Expr,
) -> &mut SelectBuilder
pub fn replace_mark( &mut self, existing_expr: &Expr, value: &Expr, ) -> &mut SelectBuilder
Replaces the selection with a new value.
This function is used to replace a specific expression within the selection.
Unlike the selection method which combines existing and new selections with AND,
this method searches for and replaces occurrences of a specific expression.
This method is primarily used to modify LEFT MARK JOIN expressions. When processing a LEFT MARK JOIN, we need to replace the placeholder expression with the actual join condition in the selection clause.
Arguments
existing_expr- The expression to replacevalue- The new expression to set as the selection
pub fn selection(&mut self, value: Option<Expr>) -> &mut SelectBuilder
pub fn group_by(&mut self, value: GroupByExpr) -> &mut SelectBuilder
pub fn cluster_by(&mut self, value: Vec<Expr>) -> &mut SelectBuilder
pub fn distribute_by(&mut self, value: Vec<Expr>) -> &mut SelectBuilder
pub fn sort_by(&mut self, value: Vec<OrderByExpr>) -> &mut SelectBuilder
pub fn having(&mut self, value: Option<Expr>) -> &mut SelectBuilder
pub fn named_window( &mut self, value: Vec<NamedWindowDefinition>, ) -> &mut SelectBuilder
pub fn qualify(&mut self, value: Option<Expr>) -> &mut SelectBuilder
pub fn value_table_mode( &mut self, value: Option<ValueTableMode>, ) -> &mut SelectBuilder
pub fn build(&self) -> Result<Select, BuilderError>