RewriteSetComparison

Struct RewriteSetComparison 

pub struct RewriteSetComparison;
Rewrite SetComparison expressions to scalar subqueries that return the correct boolean value (including SQL NULL semantics). After this rule runs, later rules such as ScalarSubqueryToJoin can decorrelate and remove the remaining subquery.

Implementations

Source

impl RewriteSetComparison

pub fn new() -> RewriteSetComparison

Create a new RewriteSetComparison optimizer rule.